==> jc-1.4.0.tar.gz: soot/toolkits/graph/SlowPseudoTopologicalOrderer.h <==
// public class soot.toolkits.graph.SlowPseudoTopologicalOrderer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14039da6d9660f73 soot_toolkits_graph_SlowPseudoTopologicalOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer_H_
#define _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object;

typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct {
	jint	BLACK;
	jint	GRAY;
	jint	WHITE;
	jboolean	REVERSE;
};
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *);
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_soot_Singletons__24Global$object *);
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, jboolean);

// Virtual methods
extern struct _jc_java_util_LinkedList$object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$computeOrder$e99ef79fd26f3ec8(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *);
extern jboolean _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$isReverseOrder$b4008fcd9aa94bc0(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *);
extern struct _jc_object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$newList$4c736451834ee04d(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *);
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$setReverseOrder$f411ccc2da2c0b4c(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, jboolean);
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$visitNode$76904f2e0e29deb5(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$computeOrder$e99ef79fd26f3ec8;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$isReverseOrder$b4008fcd9aa94bc0;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$newList$4c736451834ee04d;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$setReverseOrder$f411ccc2da2c0b4c;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$visitNode$76904f2e0e29deb5;

// Static methods
extern struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$v$2f4f3519b9c3c9a6(_jc_env *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods {
	struct _jc_java_util_LinkedList$object	*(*computeOrder$e99ef79fd26f3ec8)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *);
	jboolean	(*isReverseOrder$b4008fcd9aa94bc0)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *);
	struct _jc_object	*(*newList$4c736451834ee04d)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *);
	void	(*setReverseOrder$f411ccc2da2c0b4c)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, jboolean);
	void	(*visitNode$76904f2e0e29deb5)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods	soot_toolkits_graph_SlowPseudoTopologicalOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs {
	struct _jc_object	*stmtToColor;
	struct _jc_java_util_LinkedList$object	*order;
	struct _jc_object	*graph;
	struct _jc_object	*reverseOrder;
	struct _jc_java_util_HashMap$object	*succsMap;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs {
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_SlowPseudoTopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs {
	jboolean	mIsReversed;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_SlowPseudoTopologicalOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object {
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_SlowPseudoTopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/SlowPseudoTopologicalOrderer.h <==
// public class soot.toolkits.graph.SlowPseudoTopologicalOrderer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14039da6d9660f73 soot_toolkits_graph_SlowPseudoTopologicalOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer_H_
#define _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object;

typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct {
	jint	BLACK;
	jint	GRAY;
	jint	WHITE;
	jboolean	REVERSE;
};
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$fields_struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_LinkedList$object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$computeOrder$e99ef79fd26f3ec8(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$isReverseOrder$b4008fcd9aa94bc0(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$newList$4c736451834ee04d(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$setReverseOrder$f411ccc2da2c0b4c(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$visitNode$76904f2e0e29deb5(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$computeOrder$e99ef79fd26f3ec8;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$isReverseOrder$b4008fcd9aa94bc0;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$newList$4c736451834ee04d;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$setReverseOrder$f411ccc2da2c0b4c;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method_info$visitNode$76904f2e0e29deb5;

// Static methods
extern struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$method$v$2f4f3519b9c3c9a6(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods {
	struct _jc_java_util_LinkedList$object	*(*computeOrder$e99ef79fd26f3ec8)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isReverseOrder$b4008fcd9aa94bc0)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newList$4c736451834ee04d)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setReverseOrder$f411ccc2da2c0b4c)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, jboolean) _JC_JCNI_ATTR;
	void	(*visitNode$76904f2e0e29deb5)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vmethods	soot_toolkits_graph_SlowPseudoTopologicalOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs {
	struct _jc_object	*stmtToColor;
	struct _jc_java_util_LinkedList$object	*order;
	struct _jc_object	*graph;
	struct _jc_object	*reverseOrder;
	struct _jc_java_util_HashMap$object	*succsMap;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs {
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_SlowPseudoTopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs {
	jboolean	mIsReversed;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_SlowPseudoTopologicalOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object {
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$vtype _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_SlowPseudoTopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer_H_ */
